use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
BooK
Bruhat
CPAN
David
Ed
Etheridge
Golden
Graham
Howarth
Karen
Knop
Leon
Meta
Miyagawa
Paul
Philippe
Range
Requirements
Ricardo
Signes
Tatsuhiko
Timmermans
and
book
cpan
dagolden
dist
ether
fawaka
haarg
invocant
lib
miyagawa
mohawk2
paul
rjbs
robario
webmaster
